Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(259)

Unified Diff: components/sync/model/stub_model_type_sync_bridge.h

Issue 2458013002: [Sync] Rename ModelTypeService to ModelTypeSyncBridge. (Closed)
Patch Set: s/SetBridgeError/ErrorOnNextCall Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/model/stub_model_type_sync_bridge.h
diff --git a/components/sync/model/stub_model_type_service.h b/components/sync/model/stub_model_type_sync_bridge.h
similarity index 67%
rename from components/sync/model/stub_model_type_service.h
rename to components/sync/model/stub_model_type_sync_bridge.h
index 2b04fd0855ab905031338af28114fa650dee3b0d..73fadb9883d9e58e5235bfb58e9128432ddb9b55 100644
--- a/components/sync/model/stub_model_type_service.h
+++ b/components/sync/model/stub_model_type_sync_bridge.h
@@ -2,24 +2,24 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SERVICE_H_
-#define COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SERVICE_H_
+#ifndef COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SYNC_BRIDGE_H_
+#define COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SYNC_BRIDGE_H_
#include <memory>
#include <string>
-#include "components/sync/model/model_type_service.h"
+#include "components/sync/model/model_type_sync_bridge.h"
namespace syncer {
// A non-functional implementation of ModelTypeService for
// testing purposes.
-class StubModelTypeService : public ModelTypeService {
+class StubModelTypeSyncBridge : public ModelTypeSyncBridge {
public:
- StubModelTypeService();
- explicit StubModelTypeService(
+ StubModelTypeSyncBridge();
+ explicit StubModelTypeSyncBridge(
const ChangeProcessorFactory& change_processor_factory);
- ~StubModelTypeService() override;
+ ~StubModelTypeSyncBridge() override;
std::unique_ptr<MetadataChangeList> CreateMetadataChangeList() override;
SyncError MergeSyncData(
@@ -36,4 +36,4 @@ class StubModelTypeService : public ModelTypeService {
} // namespace syncer
-#endif // COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SERVICE_H_
+#endif // COMPONENTS_SYNC_MODEL_STUB_MODEL_TYPE_SYNC_BRIDGE_H_
« no previous file with comments | « components/sync/model/stub_model_type_service.cc ('k') | components/sync/model/stub_model_type_sync_bridge.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,24 +2,24 @@
namespace syncer {
-// A non-functional implementation of ModelTypeService for
+// A non-functional implementation of ModelTypeSyncBridge for
// testing purposes.
This is Rietveld 408576698